UI/UserInterface.py

changeset 5555
5ece4e830780
parent 5504
ba1134308a7b
child 5576
c866ec38662d
child 5587
ea526b78ee6c
--- a/UI/UserInterface.py	Fri Feb 24 18:58:27 2017 +0100
+++ b/UI/UserInterface.py	Fri Feb 24 18:59:38 2017 +0100
@@ -5669,13 +5669,14 @@
         if dlg.exec_() == QDialog.Accepted:
             # recent files, recent projects, recent multi  projects,
             # debug histories, shell histories
-            (files, projects, multiProjects, debug, shell) = dlg.getData()
+            (files, projects, multiProjects, debug, shell, vcs, plugins) = \
+                dlg.getData()
             if files:
                 # clear list of recently opened files
                 self.viewmanager.clearRecent()
             if projects:
-                # clear list of recently opened projects
-                self.project.clearRecent()
+                # clear list of recently opened projects and other histories
+                self.project.clearHistories()
             if multiProjects:
                 # clear list of recently opened multi projects
                 self.multiProject.clearRecent()
@@ -5685,7 +5686,15 @@
             if shell:
                 # clear the shell histories
                 self.shell.clearAllHistories()
-        
+            if vcs:
+                # clear the VCS related histories
+                self.pluginManager.clearPluginsPrivateData("version_control")
+            if plugins:
+                # clear private data of plug-ins not covered above
+                self.pluginManager.clearPluginsPrivateData("")
+            
+            Preferences.syncPreferences()
+    
     def __newProject(self):
         """
         Private slot to handle the NewProject signal.

eric ide

mercurial